Chaussette was created and is maintained by Tarek Ziade.

Here's a list of other contributors:

- Myoung-su Shin
- Trey Long
- Jannis Leidel
- Danilo Maurizio
- Emmanuel Raviart
- Pedro Romano
- Victor Fernandez de Alba
- Gilles Devaux
- INADA Naoki
